# -*- coding: utf-8 -*-
# Déclarations pour l'interface d'admin Django
# Copyright (C) 2010  Sylvain Beucler
#
# This file is part of Djamengo.
# 
# Djamengo is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
# 
# Djamengo is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
# 
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# 
# Author: Sylvain Beucler

from models import *
from django.contrib import admin

class ArtistAdmin(admin.ModelAdmin):
    list_display = ['id', 'name', 'url',
                    'location_country', 'location_state', 'location_city',
                    'location_latitude', 'location_longitude', ]
    list_display_links = ['id', 'name', ]
    list_filter = ['location_country', ]
    search_fields = ['id', 'name', 'mbgid', ]

class AlbumAdmin(admin.ModelAdmin):
    list_display = ['id', 'artist', 'name', 'url_html', 'filename',
                    'releasedate', 'id3genre', 'mbgid', 'license_artwork',
                    'ogg3_torrent_url_with_name_html', 'ogg3_zip_url_html', ]
    list_display_links = ['id', 'name', 'filename', ]
    date_hierarchy = 'releasedate'
    list_filter = ['id3genre', ]
    search_fields = ['id', 'name', 'filename', 'mbgid', 'artist__name', ]

class TrackAdmin(admin.ModelAdmin):
    list_display = ['id', 'name', 'album_html', 'filename', 'numalbum', 'duration', 'id3genre', 'mbgid', ]
    list_display_links = ['id', 'name', ]
    #list_filter = ['numalbum', 'id3genre', 'license']
    list_filter = ['id3genre', 'license', ]
    search_fields = ['id', 'name', 'filename', 'mbgid', 'album__name', 'album__artist__name', ]

class TagAdmin(admin.ModelAdmin):
    list_display = ['id', 'idstr', 'track_count', ]
    list_display_links = ['id', 'idstr', ]
    search_fields = ['idstr']

class TrackTagAdmin(admin.ModelAdmin):
    list_display = ['id', 'track', 'tag', 'weight', ]
    list_display_links = ['id', 'weight', ]
    search_fields = ['track__name', 'track__id',]

admin.site.register(Artist, ArtistAdmin)
admin.site.register(Album, AlbumAdmin)
admin.site.register(Track, TrackAdmin)
admin.site.register(Tag, TagAdmin)
admin.site.register(TrackTag, TrackTagAdmin)
